@@ -64,7 +64,7 @@ class EmberMugConnection:
         """Initialize connection manager."""
         self.mug = mug
         self._connect_lock: Lock = Lock()
-        self._callbacks: list[Callable[[EmberMug], None]] = []
+        self._callbacks: dict[Callable[[EmberMug], None], Callable[[], None]] = {}
         self._client: BleakClient = None  # type: ignore[assignment]
 
         self._queued_updates: set[str] = set()
@@ -79,18 +79,10 @@ class EmberMugConnection:
                 raise ValueError('The adapter option is only valid for the Linux BlueZ Backend.')
             self._client_kwargs['adapter'] = adapter
 
-    @property
-    def _device(self) -> BLEDevice:
-        return self.mug.device
-
-    @_device.setter
-    def _device(self, device: BLEDevice) -> None:
-        self.mug.device = device
-
     def set_device(self, ble_device: BLEDevice) -> None:
         """Set the ble device."""
-        logger.debug("Set new device from %s to %s", self._device, ble_device)
-        self._device = ble_device
+        logger.debug("Set new device from %s to %s", self.mug.device, ble_device)
+        self.mug.device = ble_device
 
     async def ensure_connection(self) -> None:
         """Connect to mug."""
@@ -105,14 +97,14 @@ class EmberMugConnection:
                 logger.debug("Establishing a new connection")
                 self._client = await establish_connection(
                     client_class=BleakClient,
-                    device=self._device,
-                    name=f'{self.mug.name} ({self._device.address})',
+                    device=self.mug.device,
+                    name=f'{self.mug.name} ({self.mug.device.address})',
                     disconnected_callback=self._disconnect_callback,  # type: ignore
-                    ble_device_callback=lambda: self._device,
+                    ble_device_callback=lambda: self.mug.device,
                     **self._client_kwargs,
                 )
             except (asyncio.TimeoutError, BleakError) as error:
-                logger.error("%s: Failed to connect to the mug: %s", self._device, error)
+                logger.error("%s: Failed to connect to the mug: %s", self.mug.device, error)
                 raise error
             # Attempt to pair for good measure and perform an initial update
             try:
@@ -164,14 +156,16 @@ class EmberMugConnection:
 
     def register_callback(self, callback: Callable[[EmberMug], None]) -> Callable[[], None]:
         """Register a callback to be called when the state changes."""
+        if existing_unregister_callback := self._callbacks.get(callback):
+            logger.debug("Callback %s already registered", callback)
+            return existing_unregister_callback
 
         def unregister_callback() -> None:
             if callback in self._callbacks:
-                self._callbacks.remove(callback)
+                del self._callbacks[callback]
             logger.debug("Unregistered callback: %s", callback)
 
-        if callback not in self._callbacks:
-            self._callbacks.append(callback)
+        self._callbacks[callback] = unregister_callback
         logger.debug("Registered callback: %s", callback)
         return unregister_callback
 
@@ -355,7 +349,10 @@ class EmberMugConnection:
                 PushEvent.CHARGER_DISCONNECTED,
             ):
                 # 2 -> Placed on charger, 3 -> Removed from charger
-                self.on_charging_base = event_id == PushEvent.CHARGER_CONNECTED
+                self.mug.battery = BatteryInfo(
+                    percent=self.mug.battery.percent if self.mug.battery else 0,
+                    on_charging_base=event_id == PushEvent.CHARGER_CONNECTED,
+                )
                 self._fire_callbacks()
             # All indicate changes in battery
             self._queued_updates.add("battery")
