@@ -1,7 +1,6 @@
 """Helpers for formatting values for display."""
 from __future__ import annotations
 
-from .consts import LIQUID_STATE_LABELS
 from .data import Colour
 
 
@@ -16,11 +15,6 @@ def format_led_colour(led_colour: Colour) -> str:
     return led_colour.as_hex()
 
 
-def format_liquid_state(liquid_state: int) -> str:
-    """Return human-readable liquid state."""
-    return LIQUID_STATE_LABELS[liquid_state]
-
-
 def format_liquid_level(liquid_level: int) -> str:
     """Human readable liquid level."""
     return f'{(liquid_level / 30 * 100):.2f}%'
